# nxs-analysis-tools

## Overview

nxs-analysis-tools provides a suite of tools for slicing (2D), cutting (1D), and transforming (e.g., symmetrizing, interpolating, deltaPDF) nexus format (.nxs) scattering data.

View the documentation [here](https://nxs-analysis-tools.readthedocs.io/en/stable/).

## Installation

Install nxs-analysis-tools with ``pip``:

```{code-block} console
pip install nxs-analysis-tools
```

## License

This project is licensed under the MIT License.
